Resampling (up/down), Interpolation
Functions
- downsample
- downsample samples from
srcintodstwith the ratio given bysrc.len()/dst.len()TODO: doc - downsample_
sb - uses the nightly step_by adaptor on iterator TODO: doc
- interpolate
- linearly interpolate
n_betweensamples between each consecutive pair of values insrcand write the result todst. TODO: reference paper which looked at different interpolation techniques and concluded that linear is sufficient for most purposes